## Template: {$ data.metadata.name $}

### Entities

{$ entity.entity.template_id $}

- {$ property $}: {$ value $}

{$ key $}

- {$ property $}: {$ value $}

### Relationships

{$ rel.relationship.template_id $}

- {$ property $}: {$ value $}

### Equivalences

- #### Equivalence

  {$ equ.entity.name $}
  - {$ property $}: {$ value $}

### Scenarios

{$ scenario.condition||scenario.scenario.condition $}
Actions:

1. - action: {$ action.action.action_type $}
   - {$ key $}: {$ value $}
   - {$ property $}: {$ value $} {$ property $}
     1. {$ label $}: {$ data $}
2. - action: {$ keys(action)[0] $}
   - {$ key $}: {$ value $} {$ key $}
     1. {$ label $}: {$ data $}

    {$ str_data $}